@@ -20,7 +20,7 @@ package Clownfish;
 
 use 5.008003;
 
-our $VERSION = '0.006000_002';
+our $VERSION = '0.006000003';
 $VERSION = eval $VERSION;
 our $MAJOR_VERSION = 0.006000;
 
@@ -38,14 +38,14 @@ BEGIN {
     require DynaLoader;
     our @ISA = qw( DynaLoader );
     # This loads a large number of disparate subs.
-    bootstrap Clownfish '0.6.0_2';
+    bootstrap Clownfish '0.6.0.3';
 }
 
 sub error {$Clownfish::Err::error}
 
 {
     package Clownfish::Obj;
-    our $VERSION = '0.006000_002';
+    our $VERSION = '0.006000003';
     $VERSION = eval $VERSION;
     use Carp qw( confess );
     # Clownfish objects are not thread-safe.
@@ -62,7 +62,7 @@ sub error {$Clownfish::Err::error}
 
 {
     package Clownfish::Class;
-    our $VERSION = '0.006000_002';
+    our $VERSION = '0.006000003';
     $VERSION = eval $VERSION;
 
     sub _find_parent_class {
@@ -105,7 +105,7 @@ sub error {$Clownfish::Err::error}
 
 {
     package Clownfish::Method;
-    our $VERSION = '0.006000_002';
+    our $VERSION = '0.006000003';
     $VERSION = eval $VERSION;
     no warnings 'redefine';
     sub CLONE_SKIP { 0; }
@@ -114,7 +114,7 @@ sub error {$Clownfish::Err::error}
 
 {
     package Clownfish::Err;
-    our $VERSION = '0.006000_002';
+    our $VERSION = '0.006000003';
     $VERSION = eval $VERSION;
     sub do_to_string { shift->to_string }
     use Scalar::Util qw( blessed );
@@ -153,7 +153,7 @@ sub error {$Clownfish::Err::error}
 
 {
     package Clownfish::Boolean;
-    our $VERSION = '0.006000_002';
+    our $VERSION = '0.006000003';
     $VERSION = eval $VERSION;
     use Exporter 'import';
     our @EXPORT_OK = qw( $true_singleton $false_singleton );
